@@ -11,7 +11,7 @@ use Time::HiRes qw(alarm time);
 use Carp qw(croak);
 use HTTP::Status qw(HTTP_GATEWAY_TIMEOUT);
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 sub prepare_app {
     my $self = shift;
@@ -99,7 +99,7 @@ Plack::Middleware::Timeout
 
     my $app = sub { ... };
 
-    Plack::Middleeare::Timeout->wrap(
+    Plack::Middleware::Timeout->wrap(
         $app,
         timeout  => 120,
         # optional callback to set the custom response 
@@ -156,9 +156,13 @@ optional coderef that'll get executed when we established, that time required to
 
 =back
 
+=head1 KNOWN LIMITATIONS
+
+The module won't correctly handle the IO operations in progress - where the signals aren't delivered until after the read/write ends.
+
 =head1 AUTHOR
 
-Tomasz Czepiel <tjmc@cpan.org>
+Tomasz Czepiel <tjczepiel@gmail.com>
 
 =head1 LICENCE 
 
